pub enum BundleFailurePolicy {
Abort,
AutoRetry {
max_failures: u32,
never_reject_application_ids: Arc<HashSet<GenericApplicationId>>,
},
}Expand description
Policy for handling message bundle execution failures during block execution.
Variants
Abort
Abort block execution on any bundle failure. The proposal is never modified.
AutoRetry
Automatically handle failing bundles with checkpointing and retry.
This policy is intended for use by clients when preparing proposals. It modifies the proposal by discarding or rejecting bundles that fail to execute:
- For limit errors (block too large, fuel exceeded, etc.): discard the bundle so it can be retried in a later block, unless it’s the first transaction (in which case it’s inherently too large and gets rejected).
- For bundles whose messages are all from applications in
never_reject_application_ids: discard the bundle (and subsequent bundles from the same sender) so they can be retried in a later block, and log a warning. - For all other non-limit errors: reject the bundle (triggering bounced messages).
- After
max_failuresdiscarded bundles, discard all remaining message bundles.
Fields
max_failures: u32Maximum number of discarded bundles before discarding all remaining message bundles.
never_reject_application_ids: Arc<HashSet<GenericApplicationId>>Applications whose messages must never be rejected. A failed bundle whose messages are all from such applications is discarded instead of rejected. A bundle that contains any message from an application not on this list can be rejected.