pub struct BlockExecutionOutcome {
pub messages: Vec<Vec<OutgoingMessage>>,
pub previous_message_blocks: BTreeMap<ChainId, (CryptoHash, BlockHeight)>,
pub previous_event_blocks: BTreeMap<StreamId, (CryptoHash, BlockHeight)>,
pub state_hash: CryptoHash,
pub oracle_responses: Vec<Vec<OracleResponse>>,
pub events: Vec<Vec<Event>>,
pub blobs: Vec<Vec<Blob>>,
pub operation_results: Vec<OperationResult>,
}Expand description
The messages and the state hash resulting from a ProposedBlock’s execution.
Fields
messages: Vec<Vec<OutgoingMessage>>The list of outgoing messages for each transaction.
previous_message_blocks: BTreeMap<ChainId, (CryptoHash, BlockHeight)>The hashes and heights of previous blocks that sent messages to the same recipients.
previous_event_blocks: BTreeMap<StreamId, (CryptoHash, BlockHeight)>The hashes and heights of previous blocks that published events to the same channels.
state_hash: CryptoHashThe hash of the chain’s execution state after this block.
oracle_responses: Vec<Vec<OracleResponse>>The record of oracle responses for each transaction.
events: Vec<Vec<Event>>The list of events produced by each transaction.
blobs: Vec<Vec<Blob>>The list of blobs created by each transaction.
operation_results: Vec<OperationResult>The execution result for each operation.
Implementations
Sourceimpl BlockExecutionOutcome
impl BlockExecutionOutcome
pub async fn messages( &self, ctx: &Context<'_>, ) -> Result<&Vec<Vec<OutgoingMessage>>>
pub async fn previous_message_blocks( &self, ctx: &Context<'_>, ) -> Result<&BTreeMap<ChainId, (CryptoHash, BlockHeight)>>
pub async fn previous_event_blocks( &self, ctx: &Context<'_>, ) -> Result<&BTreeMap<StreamId, (CryptoHash, BlockHeight)>>
pub async fn state_hash(&self, ctx: &Context<'_>) -> Result<&CryptoHash>
pub async fn oracle_responses( &self, ctx: &Context<'_>, ) -> Result<&Vec<Vec<OracleResponse>>>
pub async fn events(&self, ctx: &Context<'_>) -> Result<&Vec<Vec<Event>>>
pub async fn blobs(&self, ctx: &Context<'_>) -> Result<&Vec<Vec<Blob>>>
pub async fn operation_results( &self, ctx: &Context<'_>, ) -> Result<&Vec<OperationResult>>
Sourceimpl BlockExecutionOutcome
impl BlockExecutionOutcome
Sourcepub fn with(self, block: ProposedBlock) -> Block
pub fn with(self, block: ProposedBlock) -> Block
Combines this outcome with a proposed block into a full block.
Sourcepub fn oracle_blob_ids(&self) -> HashSet<BlobId>
pub fn oracle_blob_ids(&self) -> HashSet<BlobId>
Returns the IDs of all blobs referenced by oracle responses in this outcome.
Sourcepub fn has_oracle_responses(&self) -> bool
pub fn has_oracle_responses(&self) -> bool
Returns whether any transaction in this outcome recorded oracle responses.
Sourcepub fn iter_created_blobs_ids(&self) -> impl Iterator<Item = BlobId> + '_
pub fn iter_created_blobs_ids(&self) -> impl Iterator<Item = BlobId> + '_
Returns an iterator over the IDs of all blobs created in this outcome.